@@ -1,7 +1,17 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# SPDX-License-Identifier: Apache-2.0
 """Constant package."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 
 ##
 # State Machines
@@ -31,6 +41,7 @@ CREATE_PACKAGE = "Create_Package"
 SUBMIT = "Submit"
 SUBMIT_FOR_TESTING = "certificationRequest"
 CHECKOUT = "checkout"
+UNDOCHECKOUT = "UNDOCHECKOUT"
 CHECKIN = "checkin"
 APPROVE = "approve"
 DISTRIBUTE = "PROD/activate"
