@@ -1,7 +1,17 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-# SPDX-License-Identifier: Apache-2.0
 """SDC Element module."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 import logging
 from abc import ABC
 from typing import Any, Dict, Iterator, List, Union
@@ -733,6 +743,27 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
         msg = f"SDC resource {sdc_resource.name} is not a component"
         raise ResourceNotFound(msg)
 
+    def get_component_by_name(self, component_name: str) -> Component:
+        """Get resource's component by it's name.
+
+        Get component by name.
+
+        Args:
+            component_name (str): Component's name
+
+        Raises:
+            ResourceNotFound: Component with given name does not exist
+
+        Returns:
+            Component: Component object
+
+        """
+        for component in self.components:
+            if component.sdc_resource.name == component_name:
+                return component
+        msg = f"SDC resource {component_name} is not a component"
+        raise ResourceNotFound(msg)
+
     def declare_input_for_own_property(self, property_obj: Property) -> None:
         """Declare input for resource's property.
 
@@ -927,3 +958,19 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
             return None
         msg = f"Can't add resource to {self.origin_type} which is not in DRAFT status"
         raise StatusError(msg)
+
+    def archive(self) -> None:
+        """Archive resource."""
+        self.send_message(
+            "POST",
+            f"Archive {self.name} component",
+            f"{self.resource_inputs_url}/archive"
+        )
+
+    def delete(self) -> None:
+        """Delete resource."""
+        self.send_message(
+            "DELETE",
+            f"Delete {self.name} component",
+            f"{self.resource_inputs_url}"
+            )
